@@ -6,6 +6,6 @@ test_that("memory measurements work", {
   submitAndWait(reg, 1:2, resources = list(measure.memory = TRUE))
 
   expect_true(any(stri_detect_fixed(readLog(1L, reg = reg), "Memory measurement enabled")))
-  expect_numeric(reg$status$memory, any.missing = FALSE)
-  expect_true(reg$status$memory[2] > reg$status$memory[1])
+  expect_numeric(reg$status$mem.used, any.missing = FALSE)
+  expect_true(reg$status$mem.used[2] > reg$status$mem.used[1])
 })
