@@ -1,7 +1,7 @@
 context("removeRegistry")
 
 test_that("removeRegistry", {
-  reg = makeRegistry(file.dir = NA, make.default = FALSE)
+  reg = makeTestRegistry()
   expect_true(dir.exists(reg$file.dir))
   res = removeRegistry(0.01, reg = reg)
   expect_true(res)
@@ -10,7 +10,7 @@ test_that("removeRegistry", {
 
 test_that("removeRegistry resets default registry", {
   prev = batchtools$default.registry
-  reg = makeExperimentRegistry(file.dir = NA, make.default = TRUE)
+  reg = makeTestExperimentRegistry(make.default = TRUE)
   expect_is(batchtools$default.registry, "Registry")
   res = removeRegistry(0, reg = reg)
   expect_false(dir.exists(reg$file.dir))
